@@ -13,6 +13,9 @@ urlpatterns = patterns('demoproject.views',
     url(r'^multibarchart/', 'demo_multibarchart', name='demo_multibarchart'),
     url(r'^stackedareachart/', 'demo_stackedareachart', name='demo_stackedareachart'),
     url(r'^multibarhorizontalchart/', 'demo_multibarhorizontalchart', name='demo_multibarhorizontalchart'),
+    url(r'^lineplusbarchart/', 'demo_lineplusbarchart', name='demo_lineplusbarchart'),
+    url(r'^cumulativelinechart/', 'demo_cumulativelinechart', name='demo_cumulativelinechart'),
+    url(r'^discretebarchart/', 'demo_discretebarchart', name='demo_discretebarchart'),
     # url(r'^demoproject/', include('demoproject.foo.urls')),
 
     # Uncomment the admin/doc line below to enable admin documentation:
