@@ -11,7 +11,7 @@ from nvd3.NVD3Chart import NVD3Chart
 
 
 @register.simple_tag(name='load_chart')
-def load_chart(chart_type, series, container, height=400, width=400, y_is_date=False):
+def load_chart(chart_type, series, container, height=400, width=400, y_is_date=False, kwargs=None):
     """Loads the Chart objects in the container.
 
 
@@ -19,20 +19,15 @@ def load_chart(chart_type, series, container, height=400, width=400, y_is_date=F
 
     - **render_to** - id where the chart needs to be rendered to.
     """
-    if chart_type == 'pieChart':
-        chart = eval(chart_type)(name=container, height=height, width=width)
-        xdata = series['x']
-        ydata = series['y']
+    chart = eval(chart_type)(name=container, date=y_is_date, height=height, width=width)
+    xdata = series['x']
+    y_axis_list = [d for d in series.keys() if 'y' in d]
 
-        chart.add_serie(y=ydata, x=xdata)
-
-    else:
-        chart = eval(chart_type)(name=container, date=y_is_date, height=height, width=width)
-        xdata = series['x']
-        y_axis_list = [d for d in series.keys() if 'y' in d]
-        for key in y_axis_list:
-            ydata = series[key]
-            #add the serie
+    for key in y_axis_list:
+        ydata = series[key]
+        if chart_type == 'linePlusBarChart' and kwargs and key == 'y1':
+            chart.add_serie(y=ydata, x=xdata, **kwargs)
+        else:
             chart.add_serie(y=ydata, x=xdata)
 
     chart.buildhtml()
